pub struct CopyAsyncOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
barrier_copy_async_copy_length | ATTR_KEY_BARRIER_COPY_ASYNC_COPY_LENGTH | IndexAttr |
barrier_copy_async_checked | ATTR_KEY_BARRIER_COPY_ASYNC_CHECKED | BoolAttr |
Implementations
Sourceimpl CopyAsyncOp
impl CopyAsyncOp
Sourcepub fn get_attr_barrier_copy_async_copy_length<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IndexAttr>>
pub fn get_attr_barrier_copy_async_copy_length<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IndexAttr>>
Get a Ref to the value of the attribute named barrier_copy_async_copy_length.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_barrier_copy_async_copy_length(
&self,
ctx: &Context,
value: IndexAttr,
)
pub fn set_attr_barrier_copy_async_copy_length( &self, ctx: &Context, value: IndexAttr, )
Set the value of the attribute named barrier_copy_async_copy_length.
Sourcepub fn get_attr_barrier_copy_async_checked<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, BoolAttr>>
pub fn get_attr_barrier_copy_async_checked<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, BoolAttr>>
Get a Ref to the value of the attribute named barrier_copy_async_checked.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_barrier_copy_async_checked(
&self,
ctx: &Context,
value: BoolAttr,
)
pub fn set_attr_barrier_copy_async_checked( &self, ctx: &Context, value: BoolAttr, )
Set the value of the attribute named barrier_copy_async_checked.
Sourceimpl CopyAsyncOp
impl CopyAsyncOp
pub fn new( ctx: &mut Context, source: Value, destination: Value, source_length: Value, copy_length: impl Into<IndexAttr>, checked: impl Into<BoolAttr>, ) -> Self
pub fn source(&self, ctx: &Context) -> Value
pub fn source_as_use(&self, ctx: &Context) -> Use<Value>
pub fn destination(&self, ctx: &Context) -> Value
pub fn destination_as_use(&self, ctx: &Context) -> Use<Value>
pub fn source_length(&self, ctx: &Context) -> Value
pub fn source_length_as_use(&self, ctx: &Context) -> Use<Value>
pub fn copy_length<'a>(&self, ctx: &'a Context) -> Ref<'a, IndexAttr>
pub fn checked<'a>(&self, ctx: &'a Context) -> Ref<'a, BoolAttr>
pub fn set_copy_length(&self, ctx: &Context, value: impl Into<IndexAttr>)
pub fn set_checked(&self, ctx: &Context, value: impl Into<BoolAttr>)