pub struct SwitchOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
cf_switch_case_values | ATTR_KEY_CF_SWITCH_CASE_VALUES | IntegerVecAttr |
Implementations
Sourceimpl SwitchOp
impl SwitchOp
Sourcepub fn get_attr_cf_switch_case_values<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IntegerVecAttr>>
pub fn get_attr_cf_switch_case_values<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IntegerVecAttr>>
Get a Ref to the value of the attribute named cf_switch_case_values.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cf_switch_case_values(
&self,
ctx: &Context,
value: IntegerVecAttr,
)
pub fn set_attr_cf_switch_case_values( &self, ctx: &Context, value: IntegerVecAttr, )
Set the value of the attribute named cf_switch_case_values.
Sourceimpl SwitchOp
impl SwitchOp
Sourcepub fn new(
ctx: &mut Context,
condition: Value,
default_dest: Ptr<BasicBlock>,
default_dest_opds: Vec<Value>,
cases: Vec<SwitchCase>,
) -> Self
pub fn new( ctx: &mut Context, condition: Value, default_dest: Ptr<BasicBlock>, default_dest_opds: Vec<Value>, cases: Vec<SwitchCase>, ) -> Self
Create a new SwitchOp.
Sourcepub fn cases(&self, ctx: &Context) -> Vec<SwitchCase>
pub fn cases(&self, ctx: &Context) -> Vec<SwitchCase>
Get the cases of this switch operation. (The default case cannot be / isn’t included here).
Sourcepub fn default_dest(&self, ctx: &Context) -> Ptr<BasicBlock>
pub fn default_dest(&self, ctx: &Context) -> Ptr<BasicBlock>
Get the default destination of this switch operation.
Sourcepub fn default_dest_operands(&self, ctx: &Context) -> Vec<Value>
pub fn default_dest_operands(&self, ctx: &Context) -> Vec<Value>
Get the operands to pass to the default destination.