pub struct CommentOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
cube_comment_comment | ATTR_KEY_CUBE_COMMENT_COMMENT | StringAttr |
Implementations
Sourceimpl CommentOp
impl CommentOp
Sourcepub fn get_attr_cube_comment_comment<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, StringAttr>>
pub fn get_attr_cube_comment_comment<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, StringAttr>>
Get a Ref to the value of the attribute named cube_comment_comment.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cube_comment_comment(&self, ctx: &Context, value: StringAttr)
pub fn set_attr_cube_comment_comment(&self, ctx: &Context, value: StringAttr)
Set the value of the attribute named cube_comment_comment.
Sourceimpl CommentOp
impl CommentOp
pub fn new(ctx: &mut Context, comment: impl Into<StringAttr>) -> Self
pub fn comment<'a>(&self, ctx: &'a Context) -> Ref<'a, StringAttr>
pub fn set_comment(&self, ctx: &Context, value: impl Into<StringAttr>)