pub struct ShapeOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
cube_shape_buffer_idx | ATTR_KEY_CUBE_SHAPE_BUFFER_IDX | IndexAttr |
Implementations
Sourceimpl ShapeOp
impl ShapeOp
Sourcepub fn get_attr_cube_shape_buffer_idx<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IndexAttr>>
pub fn get_attr_cube_shape_buffer_idx<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IndexAttr>>
Get a Ref to the value of the attribute named cube_shape_buffer_idx.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_cube_shape_buffer_idx(&self, ctx: &Context, value: IndexAttr)
pub fn set_attr_cube_shape_buffer_idx(&self, ctx: &Context, value: IndexAttr)
Set the value of the attribute named cube_shape_buffer_idx.
Sourceimpl ShapeOp
impl ShapeOp
pub fn new( ctx: &mut Context, dim: Value, buffer_idx: impl Into<IndexAttr>, ) -> Self
pub fn dim(&self, ctx: &Context) -> Value
pub fn dim_as_use(&self, ctx: &Context) -> Use<Value>
pub fn buffer_idx<'a>(&self, ctx: &'a Context) -> Ref<'a, IndexAttr>
pub fn set_buffer_idx(&self, ctx: &Context, value: impl Into<IndexAttr>)