pub struct ElementwiseOp { /* private fields */ }Expand description
Executes a closure for each element in the matrix. Note: Unlike most matrix ops, this does not have implicit synchronization because there’s no coordination between threads.
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
matrix_elementwise_closure | ATTR_KEY_MATRIX_ELEMENTWISE_CLOSURE | IdentifierAttr |
Implementations
Sourceimpl ElementwiseOp
impl ElementwiseOp
Sourcepub fn get_attr_matrix_elementwise_closure<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IdentifierAttr>>
pub fn get_attr_matrix_elementwise_closure<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IdentifierAttr>>
Get a Ref to the value of the attribute named matrix_elementwise_closure.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_matrix_elementwise_closure(
&self,
ctx: &Context,
value: IdentifierAttr,
)
pub fn set_attr_matrix_elementwise_closure( &self, ctx: &Context, value: IdentifierAttr, )
Set the value of the attribute named matrix_elementwise_closure.
Sourceimpl ElementwiseOp
impl ElementwiseOp
pub fn new( ctx: &mut Context, matrix_in: Value, matrix_out: Value, closure: Identifier, captures: Vec<Value>, ) -> Self
pub fn matrix_in(&self, ctx: &Context) -> Value
pub fn matrix_out(&self, ctx: &Context) -> Value
pub fn closure(&self, ctx: &Context) -> Identifier
pub fn closure_captures(&self, ctx: &Context) -> Vec<Value>