pub struct LdMatrixOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
matrix_ldmatrix_factor | ATTR_KEY_MATRIX_LDMATRIX_FACTOR | IndexAttr |
matrix_ldmatrix_transpose | ATTR_KEY_MATRIX_LDMATRIX_TRANSPOSE | BoolAttr |
Implementations
Sourceimpl LdMatrixOp
impl LdMatrixOp
Sourcepub fn get_attr_matrix_ldmatrix_factor<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IndexAttr>>
pub fn get_attr_matrix_ldmatrix_factor<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IndexAttr>>
Get a Ref to the value of the attribute named matrix_ldmatrix_factor.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_matrix_ldmatrix_factor(&self, ctx: &Context, value: IndexAttr)
pub fn set_attr_matrix_ldmatrix_factor(&self, ctx: &Context, value: IndexAttr)
Set the value of the attribute named matrix_ldmatrix_factor.
Sourcepub fn get_attr_matrix_ldmatrix_transpose<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, BoolAttr>>
pub fn get_attr_matrix_ldmatrix_transpose<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, BoolAttr>>
Get a Ref to the value of the attribute named matrix_ldmatrix_transpose.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_matrix_ldmatrix_transpose(&self, ctx: &Context, value: BoolAttr)
pub fn set_attr_matrix_ldmatrix_transpose(&self, ctx: &Context, value: BoolAttr)
Set the value of the attribute named matrix_ldmatrix_transpose.
Sourceimpl LdMatrixOp
impl LdMatrixOp
pub fn new( ctx: &mut Context, ptr: Value, out_arr: Value, factor: impl Into<IndexAttr>, transpose: impl Into<BoolAttr>, ) -> Self
pub fn ptr(&self, ctx: &Context) -> Value
pub fn ptr_as_use(&self, ctx: &Context) -> Use<Value>
pub fn out_arr(&self, ctx: &Context) -> Value
pub fn out_arr_as_use(&self, ctx: &Context) -> Use<Value>
pub fn factor<'a>(&self, ctx: &'a Context) -> Ref<'a, IndexAttr>
pub fn transpose<'a>(&self, ctx: &'a Context) -> Ref<'a, BoolAttr>
pub fn set_factor(&self, ctx: &Context, value: impl Into<IndexAttr>)
pub fn set_transpose(&self, ctx: &Context, value: impl Into<BoolAttr>)