pub struct RowIndexOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
matrix_row_index_matrix_ty | ATTR_KEY_MATRIX_ROW_INDEX_MATRIX_TY | MatrixTypeAttr |
Implementations
Sourceimpl RowIndexOp
impl RowIndexOp
Sourcepub fn get_attr_matrix_row_index_matrix_ty<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, MatrixTypeAttr>>
pub fn get_attr_matrix_row_index_matrix_ty<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, MatrixTypeAttr>>
Get a Ref to the value of the attribute named matrix_row_index_matrix_ty.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_matrix_row_index_matrix_ty(
&self,
ctx: &Context,
value: MatrixTypeAttr,
)
pub fn set_attr_matrix_row_index_matrix_ty( &self, ctx: &Context, value: MatrixTypeAttr, )
Set the value of the attribute named matrix_row_index_matrix_ty.
Sourceimpl RowIndexOp
impl RowIndexOp
pub fn new( ctx: &mut Context, lane_id: Value, i: Value, matrix_ty: impl Into<MatrixTypeAttr>, ) -> Self
pub fn lane_id(&self, ctx: &Context) -> Value
pub fn lane_id_as_use(&self, ctx: &Context) -> Use<Value>
pub fn i(&self, ctx: &Context) -> Value
pub fn i_as_use(&self, ctx: &Context) -> Use<Value>
pub fn matrix_ty<'a>(&self, ctx: &'a Context) -> Ref<'a, MatrixTypeAttr>
pub fn set_matrix_ty(&self, ctx: &Context, value: impl Into<MatrixTypeAttr>)