pub struct StMatrixOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
matrix_stmatrix_factor | ATTR_KEY_MATRIX_STMATRIX_FACTOR | IndexAttr |
matrix_stmatrix_transpose | ATTR_KEY_MATRIX_STMATRIX_TRANSPOSE | BoolAttr |
Implementations
Sourceimpl StMatrixOp
impl StMatrixOp
Sourcepub fn get_attr_matrix_stmatrix_factor<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IndexAttr>>
pub fn get_attr_matrix_stmatrix_factor<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IndexAttr>>
Get a Ref to the value of the attribute named matrix_stmatrix_factor.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_matrix_stmatrix_factor(&self, ctx: &Context, value: IndexAttr)
pub fn set_attr_matrix_stmatrix_factor(&self, ctx: &Context, value: IndexAttr)
Set the value of the attribute named matrix_stmatrix_factor.
Sourcepub fn get_attr_matrix_stmatrix_transpose<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, BoolAttr>>
pub fn get_attr_matrix_stmatrix_transpose<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, BoolAttr>>
Get a Ref to the value of the attribute named matrix_stmatrix_transpose.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_matrix_stmatrix_transpose(&self, ctx: &Context, value: BoolAttr)
pub fn set_attr_matrix_stmatrix_transpose(&self, ctx: &Context, value: BoolAttr)
Set the value of the attribute named matrix_stmatrix_transpose.
Sourceimpl StMatrixOp
impl StMatrixOp
pub fn new( ctx: &mut Context, registers: Value, destination: Value, factor: impl Into<IndexAttr>, transpose: impl Into<BoolAttr>, ) -> Self
pub fn registers(&self, ctx: &Context) -> Value
pub fn registers_as_use(&self, ctx: &Context) -> Use<Value>
pub fn destination(&self, ctx: &Context) -> Value
pub fn destination_as_use(&self, ctx: &Context) -> Use<Value>
pub fn factor<'a>(&self, ctx: &'a Context) -> Ref<'a, IndexAttr>
pub fn transpose<'a>(&self, ctx: &'a Context) -> Ref<'a, BoolAttr>
pub fn set_factor(&self, ctx: &Context, value: impl Into<IndexAttr>)
pub fn set_transpose(&self, ctx: &Context, value: impl Into<BoolAttr>)