pub struct StoreOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
matrix_store_layout | ATTR_KEY_MATRIX_STORE_LAYOUT | MatrixLayoutAttr |
Implementations
Sourceimpl StoreOp
impl StoreOp
Sourcepub fn get_attr_matrix_store_layout<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, MatrixLayoutAttr>>
pub fn get_attr_matrix_store_layout<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, MatrixLayoutAttr>>
Get a Ref to the value of the attribute named matrix_store_layout.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_matrix_store_layout(
&self,
ctx: &Context,
value: MatrixLayoutAttr,
)
pub fn set_attr_matrix_store_layout( &self, ctx: &Context, value: MatrixLayoutAttr, )
Set the value of the attribute named matrix_store_layout.
Sourceimpl StoreOp
impl StoreOp
pub fn new( ctx: &mut Context, matrix: Value, destination: Value, stride: Value, layout: impl Into<MatrixLayoutAttr>, ) -> Self
pub fn matrix(&self, ctx: &Context) -> Value
pub fn matrix_as_use(&self, ctx: &Context) -> Use<Value>
pub fn destination(&self, ctx: &Context) -> Value
pub fn destination_as_use(&self, ctx: &Context) -> Use<Value>
pub fn stride(&self, ctx: &Context) -> Value
pub fn stride_as_use(&self, ctx: &Context) -> Use<Value>
pub fn layout<'a>(&self, ctx: &'a Context) -> Ref<'a, MatrixLayoutAttr>
pub fn set_layout(&self, ctx: &Context, value: impl Into<MatrixLayoutAttr>)