pub struct CopyOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
memory_copy_len | ATTR_KEY_MEMORY_COPY_LEN | IndexAttr |
Implementations
Sourceimpl CopyOp
impl CopyOp
Sourcepub fn get_attr_memory_copy_len<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IndexAttr>>
pub fn get_attr_memory_copy_len<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IndexAttr>>
Get a Ref to the value of the attribute named memory_copy_len.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_memory_copy_len(&self, ctx: &Context, value: IndexAttr)
pub fn set_attr_memory_copy_len(&self, ctx: &Context, value: IndexAttr)
Set the value of the attribute named memory_copy_len.
Sourceimpl CopyOp
impl CopyOp
pub fn new( ctx: &mut Context, source: Value, destination: Value, len: impl Into<IndexAttr>, ) -> Self
pub fn source(&self, ctx: &Context) -> Value
pub fn source_as_use(&self, ctx: &Context) -> Use<Value>
pub fn destination(&self, ctx: &Context) -> Value
pub fn destination_as_use(&self, ctx: &Context) -> Use<Value>
pub fn len<'a>(&self, ctx: &'a Context) -> Ref<'a, IndexAttr>
pub fn set_len(&self, ctx: &Context, value: impl Into<IndexAttr>)