IndexOp

Struct IndexOp 

pub struct IndexOp { /* private fields */ }
Attribute(s):

Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.

NameStatic Name IdentifierType
memory_index_checkedATTR_KEY_MEMORY_INDEX_CHECKEDUnitAttr

Implementations

Source

impl IndexOp

pub fn get_attr_memory_index_checked<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, UnitAttr>>

Get a Ref to the value of the attribute named memory_index_checked. The Ref is a borrow of the containing Operation object.

pub fn set_attr_memory_index_checked(&self, ctx: &Context, value: UnitAttr)

Set the value of the attribute named memory_index_checked.

Source

impl IndexOp

pub fn new( ctx: &mut Context, base: Value, index: Value, checked: Option<UnitAttr>, ) -> Self

pub fn base(&self, ctx: &Context) -> Value

pub fn base_as_use(&self, ctx: &Context) -> Use<Value>

pub fn index(&self, ctx: &Context) -> Value

pub fn index_as_use(&self, ctx: &Context) -> Use<Value>

pub fn checked<'a>(&self, ctx: &'a Context) -> bool

pub fn set_checked(&self, ctx: &Context)

pub fn remove_checked(&self, ctx: &Context)

Source

impl IndexOp

pub fn maybe_checked( ctx: &mut Context, base: Value, index: Value, checked: bool, ) -> Self