pub struct CreateLayoutOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
spirv_create_layout_rank | ATTR_KEY_SPIRV_CREATE_LAYOUT_RANK | IndexAttr |
Implementations
Sourceimpl CreateLayoutOp
impl CreateLayoutOp
Sourcepub fn get_attr_spirv_create_layout_rank<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IndexAttr>>
pub fn get_attr_spirv_create_layout_rank<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IndexAttr>>
Get a Ref to the value of the attribute named spirv_create_layout_rank.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_spirv_create_layout_rank(&self, ctx: &Context, value: IndexAttr)
pub fn set_attr_spirv_create_layout_rank(&self, ctx: &Context, value: IndexAttr)
Set the value of the attribute named spirv_create_layout_rank.