pub struct SyncAsyncProxyOp { /* private fields */ }Expand description
Fences the async proxy in CUDA, to make shared memory available to it. Does not implement
Synchronizes, because it works only as a memory availability barrier with an outside chip.
It does not synchronize the actual threads, and is typically called only by the TMA leader.
Implementations