CompositeExtractOp

Struct CompositeExtractOp 

pub struct CompositeExtractOp { /* private fields */ }
Attribute(s):

Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.

NameStatic Name IdentifierType
composite_extract_indexATTR_KEY_COMPOSITE_EXTRACT_INDEXIndexAttr

Implementations

Source

impl CompositeExtractOp

pub fn get_attr_composite_extract_index<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IndexAttr>>

Get a Ref to the value of the attribute named composite_extract_index. The Ref is a borrow of the containing Operation object.

pub fn set_attr_composite_extract_index(&self, ctx: &Context, value: IndexAttr)

Set the value of the attribute named composite_extract_index.

Source

impl CompositeExtractOp

pub fn new( ctx: &mut Context, composite: Value, index: impl Into<IndexAttr>, ) -> Self

pub fn composite(&self, ctx: &Context) -> Value

pub fn composite_as_use(&self, ctx: &Context) -> Use<Value>

pub fn index<'a>(&self, ctx: &'a Context) -> Ref<'a, IndexAttr>

pub fn set_index(&self, ctx: &Context, value: impl Into<IndexAttr>)