pub enum AddressType {
U32 = 0,
U64 = 1,
}Expand description
The type used for addressing storage types in a kernel.
This is the type usize maps to when used in a kernel, with isize being mapped to the signed
equivalent.
Variants
Implementations
Sourceimpl AddressType
impl AddressType
Sourcepub fn from_len(num_elems: usize) -> Self
pub fn from_len(num_elems: usize) -> Self
Pick an address type based on the number of elements in a buffer.
Sourcepub fn from_len_signed(num_elems: usize) -> Self
pub fn from_len_signed(num_elems: usize) -> Self
Pick an address type based on the number of elements in a buffer, for a kernel that requires signed indices.
pub fn register(&self, state: &mut GlobalState)
pub fn unsigned_type(&self) -> ElemType
pub fn signed_type(&self) -> ElemType
pub fn size(&self) -> usize
pub fn size_bits(&self) -> usize