BarrierOps

Enum BarrierOps 

pub enum BarrierOps {
Show 15 variants Init { barrier: Value, is_elected: Value, arrival_count: Value, }, InitManual { barrier: Value, arrival_count: Value, }, MemCopyAsync { barrier: Value, source: Value, destination: Value, source_length: Value, }, MemCopyAsyncCooperative { barrier: Value, source: Value, destination: Value, source_length: Value, }, MemCopyAsyncTx { barrier: Value, source: Value, destination: Value, source_length: Value, }, CopyAsync { source: Value, destination: Value, source_length: Value, copy_length: u32, checked: bool, }, TmaLoad { barrier: Value, tensor_map: Value, destination: Value, indices: Vec<Value>, }, TmaLoadIm2col { barrier: Value, tensor_map: Value, destination: Value, indices: Vec<Value>, offsets: Vec<Value>, }, Arrive { barrier: Value, }, ArriveTx { barrier: Value, arrive_count_update: Value, transaction_count_update: Value, }, CommitCopyAsync { barrier: Value, }, ExpectTx { barrier: Value, transaction_count_update: Value, }, Wait { barrier: Value, token: Value, }, WaitParity { barrier: Value, phase: Value, }, ArriveAndWait { barrier: Value, },
}
Operations available on a barrier

Variants



Init

Initialize the barrier, optionally with a cta proxy fence

Fields

barrier: Value
is_elected: Value
arrival_count: Value


InitManual

Manually initialize the barrier with an arrival count, without any sync or election handling

Fields

barrier: Value
arrival_count: Value


MemCopyAsync

Copy source to destination

Fields

barrier: Value
source: Value
destination: Value
source_length: Value


MemCopyAsyncCooperative

Copy source to destination, with cooperative behaviour

Fields

barrier: Value
source: Value
destination: Value
source_length: Value


MemCopyAsyncTx

Copy source to destination, with transaction count

Fields

barrier: Value
source: Value
destination: Value
source_length: Value


CopyAsync

Copy source to destination

Fields

source: Value
destination: Value
source_length: Value
copy_length: u32
checked: bool


TmaLoad

Fields

barrier: Value
tensor_map: Value
destination: Value
indices: Vec<Value>


TmaLoadIm2col

Fields

barrier: Value
tensor_map: Value
destination: Value
indices: Vec<Value>
offsets: Vec<Value>


Arrive

Arrives at the barrier (decrements barrier count)

Fields

barrier: Value


ArriveTx

Fields

barrier: Value
arrive_count_update: Value
transaction_count_update: Value


CommitCopyAsync

Fields

barrier: Value


ExpectTx

Fields

barrier: Value
transaction_count_update: Value


Wait

Fields

barrier: Value
token: Value


WaitParity

Fields

barrier: Value
phase: Value


ArriveAndWait

Waits until data is loaded

Fields

barrier: Value