pub enum ElemType {
Index,
Float(FloatKind),
Int(IntKind),
UInt(UIntKind),
Bool,
}Expand description
Conceptual element type, not necessarily the physical type used in the code
Variants
Implementations
Sourceimpl ElemType
impl ElemType
Sourcepub fn from_scale_dtype(dtype: ScaleDtype) -> Self
pub fn from_scale_dtype(dtype: ScaleDtype) -> Self
Creates an elem type that correspond to the given ScaleDtype.
Sourcepub fn from_quant_value(quant_value: QuantValue) -> Self
pub fn from_quant_value(quant_value: QuantValue) -> Self
Creates an elem type that correspond to the given QuantValue.
pub fn to_type(&self, ctx: &Context) -> TypeHandle
Sourcepub fn constant(&self, val: ConstantValue) -> ExpandValue
pub fn constant(&self, val: ConstantValue) -> ExpandValue
Create a constant from a constant value.
The output will have the same type as the element.
pub fn with_vector_size(self, vector_size: VectorSize) -> Type
pub fn expand_size(&self, address_type: AddressType) -> usize
pub const fn min_vector_size(&self) -> u8
pub fn is_int(&self) -> bool
pub fn is_signed_int(&self) -> bool
pub fn is_unsigned_int(&self) -> bool
pub fn is_float(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn as_float(&self) -> Option<FloatKind>
pub fn max_variable(&self, scope: &Scope) -> ExpandValue
pub fn min_variable(&self) -> ExpandValue
pub fn epsilon(&self) -> f64