pub enum FloatKind {
Show 13 variants
E2M1,
E2M1x2,
E2M3,
E3M2,
E4M3,
E5M2,
UE8M0,
F16,
BF16,
Flex32,
F32,
TF32,
F64,
}Variants
E2M1
FP4, 2 bit exponent, 1 bit mantissa
E2M1x2
FP4x2, 2 bit exponent, 1 bit mantissa
E2M3
FP6, 2 bit exponent, 3 bit mantissa Note: represented by an 8-bit value, with the upper two bits being insignificant
E3M2
FP6, 3 bit exponent, 2 bit mantissa Note: represented by an 8-bit value, with the upper two bits being insignificant
E4M3
FP8, 4 bit exponent, 3 bit mantissa
E5M2
FP8, 5 bit exponent, 2 bit mantissa
UE8M0
FP8, unsigned, 8 bit exponent, 0 bit mantissa
F16
BF16
Flex32
F32
TF32
F64
Implementations