pub enum Metadata {
Stride {
dim: Value,
list: Value,
},
Shape {
dim: Value,
list: Value,
},
BufferLength {
list: Value,
},
}Expand description
All metadata that can be accessed in a shader.
Variants
Stride
The stride of an array at the given dimension.
Shape
The shape of an array at the given dimension.
BufferLength
The length of an array’s underlying buffer.