CubeMmaConfig

Struct CubeMmaConfig 

pub struct CubeMmaConfig {
    pub a_type: StorageType,
    pub b_type: StorageType,
    pub cd_type: StorageType,
    pub m_granularity: u32,
    pub m_max: u32,
    pub n_granularity: u32,
    pub n_max: u32,
    pub k_granularity: u32,
    pub k_max: u32,
    pub units_per_block: Option<u32>,
}
Shape and element types of a valid flexible MMA configuration Only Vulkan for now, but this should also be usable for wgmma/xmma on datacenter CUDA. Actual matrix size must be multiple of granularity and <= max.

Fields

a_type: StorageType

Element of the A matrix

b_type: StorageType

Element of the B matrix

cd_type: StorageType

Element of the C/D matrices

m_granularity: u32

The granularity of the matrix on the m dimension

m_max: u32

The maximum value for m

n_granularity: u32

The size of the matrix on the n dimension

n_max: u32

The maximum value for n

k_granularity: u32

The size of the matrix on the k dimension

k_max: u32

The maximum value for k

units_per_block: Option<u32>

The number of units that must be in the cube for this configuration to be valid. None means it’s always valid (but might still have an optimal value).