pub struct MatmulFeatures {
pub cmma: BTreeSet<MmaConfig>,
pub cube_mma: BTreeSet<CubeMmaConfig>,
pub mma: BTreeSet<MmaConfig>,
pub scaled_mma: BTreeSet<ScaledMmaConfig>,
pub ldmatrix: BTreeSet<StorageType>,
pub stmatrix: BTreeSet<StorageType>,
pub cmma_tensor_addressing: bool,
}Expand description
Matrix multiplication-related features
Fields
cmma: BTreeSet<MmaConfig>The cmma feature enables cooperative matrix-multiply and accumulate operations.
cube_mma: BTreeSet<CubeMmaConfig>Cube MMA is like cmma but at the cube level, rather than the plane level.
Loading may be staged in shared memory by the driver on Vulkan - check
cube_mma_reserved_shared_memory
to take this into account when generating a matmul config.
mma: BTreeSet<MmaConfig>The manual MMA feature enables cooperative matrix-multiply with manually managed data movement
scaled_mma: BTreeSet<ScaledMmaConfig>Scaled MMA allows combining matrix multiplication with unscaling quantized values into a single instruction. Scales must fit a specific layout and block size.
ldmatrix: BTreeSet<StorageType>Types supported for ldmatrix, if any
stmatrix: BTreeSet<StorageType>Types supported by stmatrix, if any
cmma_tensor_addressing: boolWhether tensor addressing is supported for CMMA load/store