ModuleOp

Struct ModuleOp 

pub struct ModuleOp { /* private fields */ }
Represents a module, a top level container operation.

See MLIR’s builtin.module. It contains a single Graph region containing a single block which can contain any operations and does not have a terminator.

Implementations

Source

impl ModuleOp

pub fn new(ctx: &mut Context, name: Identifier) -> ModuleOp

Create a new ModuleOp. The underlying Operation is not linked to a BasicBlock. The returned module has a single crate::region::Region with a single (BasicBlock)crate::basic_block::BasicBlock.