SmallMap

Struct SmallMap 

pub struct SmallMap<K, V, const N: usize>(/* private fields */);
A hash map, with a fast non-cryptographic hasher and deterministic iteration order, optimized for the common case of very few entries.

Up to N entries are stored inline, in a flat, linearly-scanned array, with no heap allocation and no hashing. Once an insert grows the map past N entries, it transparently and permanently promotes itself to an IMap

Implementations

Source

impl<K, V, const N: usize> SmallMap<K, V, N>

pub fn new() -> SmallMap<K, V, N>

Creates an empty SmallMap. Does not allocate until it grows past N entries.

pub fn is_inline(&self) -> bool

Returns true if this map has not (yet) grown past N entries, i.e., is still using inline, non-heap-allocated storage.

pub fn len(&self) -> usize

Returns the number of elements in the map.

pub fn is_empty(&self) -> bool

Returns true if the map contains no elements.

pub fn clear(&mut self)

Clears the map, removing all key-value pairs. A previously promoted map stays promoted; see the SmallMap documentation.

pub fn retain<F>(&mut self, f: F)
where F: FnMut(&K, &mut V) -> bool,

Retains only the elements specified by the predicate.

In other words, remove all pairs (k, v) such that f(&k, &mut v) returns false.

pub fn iter(&self) -> MapIter<'_, K, V>

Returns an iterator over the map’s key-value pairs.

pub fn iter_mut(&mut self) -> MapIterMut<'_, K, V>

Returns a mutable iterator over the map’s key-value pairs.

pub fn keys(&self) -> impl Iterator<Item = &K>

Returns an iterator over the map’s keys.

pub fn values(&self) -> impl Iterator<Item = &V>

Returns an iterator over the map’s values.

pub fn values_mut(&mut self) -> impl Iterator<Item = &mut V>

Returns a mutable iterator over the map’s values.

Source

impl<K, V, const N: usize> SmallMap<K, V, N>
where K: Hash + Eq,

pub fn insert(&mut self, key: K, value: V) -> Option<V>

Inserts a key-value pair into the map.

If the map did not have this key present, None is returned. If the map did have this key present, the value is updated, and the old value is returned. The key is not updated, though; this matters for types that can be == without being identical.

pub fn get<Q>(&self, key: &Q) -> Option<&V>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns a reference to the value corresponding to the key.

pub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns a mutable reference to the value corresponding to the key.

pub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns the key-value pair corresponding to the supplied key.

pub fn contains_key<Q>(&self, key: &Q) -> bool
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns true if the map contains a value for the specified key.

pub fn remove<Q>(&mut self, key: &Q) -> Option<V>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Removes a key from the map, returning the value at the key if the key was previously in the map.

pub fn entry(&mut self, key: K) -> Entry<'_, K, V, N>

Gets the given key’s corresponding entry in the map for in-place manipulation.