SmallSet

Struct SmallSet 

pub struct SmallSet<T, const N: usize>(/* private fields */);
A hash set, with a fast non-cryptographic hasher and deterministic iteration order, optimized for the common case of very few elements.

Up to N entries are stored inline, in a flat, linearly-scanned array, with no heap allocation and no hashing. Once an insert grows the set past N entries, it transparently and permanently promotes itself to an ISet

Implementations

Source

impl<T, const N: usize> SmallSet<T, N>

pub fn new() -> SmallSet<T, N>

Creates an empty SmallSet. Does not allocate until it grows past N elements.

pub fn is_inline(&self) -> bool

Returns true if this set has not (yet) grown past N elements, i.e., is still using inline, non-heap-allocated storage.

pub fn len(&self) -> usize

Returns the number of elements in the set.

pub fn is_empty(&self) -> bool

Returns true if the set contains no elements.

pub fn clear(&mut self)

Clears the set, removing all values. A previously promoted set stays promoted; see the SmallMap documentation.

pub fn retain<F>(&mut self, f: F)
where F: FnMut(&T) -> bool,

Retains only the elements specified by the predicate.

In other words, remove all values v such that f(&v) returns false.

pub fn iter(&self) -> SetIter<'_, T>

Returns an iterator over the set’s elements.

Source

impl<T, const N: usize> SmallSet<T, N>
where T: Hash + Eq,

pub fn insert(&mut self, value: T) -> bool

Adds a value to the set.

If the set did not have this value present, true is returned. If the set did have this value present, false is returned.

pub fn contains<Q>(&self, value: &Q) -> bool
where T: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns true if the set contains a value.

pub fn get<Q>(&self, value: &Q) -> Option<&T>
where T: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns a reference to the value in the set, if any, that is equal to the given value.

pub fn remove<Q>(&mut self, value: &Q) -> bool
where T: Borrow<Q>, Q: Hash + Eq + ?Sized,

Removes a value from the set. Returns whether the value was present.