Dim3

Struct Dim3 

pub struct Dim3 {
    pub x: u32,
    pub y: u32,
    pub z: u32,
}
The number of units across all 3 axis totalling to the number of working units in a cube.

Fields

x: u32

The number of units in the x axis.

y: u32

The number of units in the y axis.

z: u32

The number of units in the z axis.

Implementations

Source

impl Dim3

pub const fn new_single() -> Self

Create a new Dim3 with x = y = z = 1.

pub const fn new_1d(x: u32) -> Self

Create a new Dim3 with the given x, and y = z = 1.

pub const fn new_2d(x: u32, y: u32) -> Self

Create a new dim3 with the given x and y, and z = 1.

pub const fn new_3d(x: u32, y: u32, z: u32) -> Self

Create a new Dim3 with the given x, y and z. This is equivalent to the new function.

pub const fn num_elems(&self) -> u32

Total numbers of units per cube

pub const fn can_contain(&self, other: Dim3) -> bool

Whether this Dim3 can fully contain other