pub struct AggregateExtractOperands {
pub aggregate: Value,
pub field: usize,
}Fields
aggregate: Valuefield: usizeTrait Implementations
Sourceimpl Clone for AggregateExtractOperands
impl Clone for AggregateExtractOperands
Sourcefn clone(&self) -> AggregateExtractOperands
fn clone(&self) -> AggregateExtractOperands
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AggregateExtractOperands
impl Debug for AggregateExtractOperands
Sourceimpl<'de> Deserialize<'de> for AggregateExtractOperands
impl<'de> Deserialize<'de> for AggregateExtractOperands
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AggregateExtractOperands
Sourceimpl From<AggregateExtractOperands> for Operation
impl From<AggregateExtractOperands> for Operation
Sourcefn from(value: AggregateExtractOperands) -> Self
fn from(value: AggregateExtractOperands) -> Self
Converts to this type from the input type.
Sourceimpl Hash for AggregateExtractOperands
impl Hash for AggregateExtractOperands
Sourceimpl OperationArgs for AggregateExtractOperands
impl OperationArgs for AggregateExtractOperands
Sourcefn from_args(args: &[Value]) -> Option<Self>
fn from_args(args: &[Value]) -> Option<Self>
Construct this type from a list of arguments. If not all arguments are
Value, returns
NoneSourcefn as_args(&self) -> Option<Vec<Value>>
fn as_args(&self) -> Option<Vec<Value>>
Turns this type into a flat list of arguments. If not all arguments are
Value,
returns NoneSourcefn as_args_mut(&mut self) -> Option<Vec<&mut Value>>
fn as_args_mut(&mut self) -> Option<Vec<&mut Value>>
Turns this type into a flat list of arguments. If not all arguments are
Value,
returns NoneSourcefn sanitize_args_ptr(&mut self, scope: &Scope)
fn sanitize_args_ptr(&mut self, scope: &Scope)
Sanitize args for the
ptr constraint, loading inputs from pointers for ops that take values.
This is needed because Rust “helpfully” auto-derefs references, skipping the explicit deref
code that inserts a Memory::Load.fn read_pointers(&self) -> Vec<Value>
fn write_pointers(&self) -> Vec<Value>
Sourceimpl PartialEq for AggregateExtractOperands
impl PartialEq for AggregateExtractOperands
Sourceimpl Serialize for AggregateExtractOperands
impl Serialize for AggregateExtractOperands
impl StructuralPartialEq for AggregateExtractOperands