pub struct Allocator { /* private fields */ }Expand description
An allocator for the static single-assignment
values of a kernel. For mutable variables, the value is the root pointer that serves as a
handle into the place where the inner value is stored (memref, Place, lvalue, whatever your
compiler of choice uses as a name). This means all values are immutable, and only the memory
referenced by them may be mutated.
Implementations
Sourceimpl Allocator
impl Allocator
pub fn clone_deep(&self) -> Self
Sourcepub fn create_value(&self, ty: Type) -> Value
pub fn create_value(&self, ty: Type) -> Value
Create a new immutable value of type specified by ty.
pub fn new_local_index(&self) -> u32
pub fn current_local_index(&self) -> u32