pub struct CompareAndSwapOperands {
pub ptr: Value,
pub cmp: Value,
pub val: Value,
}Fields
ptr: Valuecmp: Valueval: ValueTrait Implementations
Sourceimpl Clone for CompareAndSwapOperands
impl Clone for CompareAndSwapOperands
Sourcefn clone(&self) -> CompareAndSwapOperands
fn clone(&self) -> CompareAndSwapOperands
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompareAndSwapOperands
impl Debug for CompareAndSwapOperands
Sourceimpl<'de> Deserialize<'de> for CompareAndSwapOperands
impl<'de> Deserialize<'de> for CompareAndSwapOperands
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompareAndSwapOperands
Sourceimpl Hash for CompareAndSwapOperands
impl Hash for CompareAndSwapOperands
Sourceimpl OperationArgs for CompareAndSwapOperands
impl OperationArgs for CompareAndSwapOperands
Sourcefn from_args(args: &[Value]) -> Option<Self>
fn from_args(args: &[Value]) -> Option<Self>
Construct this type from a list of arguments. If not all arguments are
Value, returns
NoneSourcefn as_args(&self) -> Option<Vec<Value>>
fn as_args(&self) -> Option<Vec<Value>>
Turns this type into a flat list of arguments. If not all arguments are
Value,
returns NoneSourcefn as_args_mut(&mut self) -> Option<Vec<&mut Value>>
fn as_args_mut(&mut self) -> Option<Vec<&mut Value>>
Turns this type into a flat list of arguments. If not all arguments are
Value,
returns NoneSourcefn sanitize_args_ptr(&mut self, scope: &Scope)
fn sanitize_args_ptr(&mut self, scope: &Scope)
Sanitize args for the
ptr constraint, loading inputs from pointers for ops that take values.
This is needed because Rust “helpfully” auto-derefs references, skipping the explicit deref
code that inserts a Memory::Load.fn read_pointers(&self) -> Vec<Value>
fn write_pointers(&self) -> Vec<Value>
Sourceimpl PartialEq for CompareAndSwapOperands
impl PartialEq for CompareAndSwapOperands
Sourceimpl Serialize for CompareAndSwapOperands
impl Serialize for CompareAndSwapOperands
impl StructuralPartialEq for CompareAndSwapOperands