pub struct FmaOperands {
pub a: Value,
pub b: Value,
pub c: Value,
}Fields
a: Valueb: Valuec: ValueTrait Implementations
Sourceimpl Clone for FmaOperands
impl Clone for FmaOperands
Sourcefn clone(&self) -> FmaOperands
fn clone(&self) -> FmaOperands
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FmaOperands
impl Debug for FmaOperands
Sourceimpl<'de> Deserialize<'de> for FmaOperands
impl<'de> Deserialize<'de> for FmaOperands
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FmaOperands
Sourceimpl Hash for FmaOperands
impl Hash for FmaOperands
Sourceimpl OperationArgs for FmaOperands
impl OperationArgs for FmaOperands
Sourcefn from_args(args: &[Value]) -> Option<Self>
fn from_args(args: &[Value]) -> Option<Self>
Construct this type from a list of arguments. If not all arguments are
Value, returns
NoneSourcefn as_args(&self) -> Option<Vec<Value>>
fn as_args(&self) -> Option<Vec<Value>>
Turns this type into a flat list of arguments. If not all arguments are
Value,
returns NoneSourcefn as_args_mut(&mut self) -> Option<Vec<&mut Value>>
fn as_args_mut(&mut self) -> Option<Vec<&mut Value>>
Turns this type into a flat list of arguments. If not all arguments are
Value,
returns NoneSourcefn sanitize_args_ptr(&mut self, scope: &Scope)
fn sanitize_args_ptr(&mut self, scope: &Scope)
Sanitize args for the
ptr constraint, loading inputs from pointers for ops that take values.
This is needed because Rust “helpfully” auto-derefs references, skipping the explicit deref
code that inserts a Memory::Load.fn read_pointers(&self) -> Vec<Value>
fn write_pointers(&self) -> Vec<Value>
Sourceimpl PartialEq for FmaOperands
impl PartialEq for FmaOperands
Sourceimpl Serialize for FmaOperands
impl Serialize for FmaOperands
impl StructuralPartialEq for FmaOperands