pub struct ReinterpretSliceOperands {
pub input: Value,
pub vector_size: u32,
}Fields
input: Valuevector_size: u32Trait Implementations
Sourceimpl Clone for ReinterpretSliceOperands
impl Clone for ReinterpretSliceOperands
Sourcefn clone(&self) -> ReinterpretSliceOperands
fn clone(&self) -> ReinterpretSliceOperands
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReinterpretSliceOperands
impl Debug for ReinterpretSliceOperands
Sourceimpl<'de> Deserialize<'de> for ReinterpretSliceOperands
impl<'de> Deserialize<'de> for ReinterpretSliceOperands
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReinterpretSliceOperands
Sourceimpl Hash for ReinterpretSliceOperands
impl Hash for ReinterpretSliceOperands
Sourceimpl OperationArgs for ReinterpretSliceOperands
impl OperationArgs for ReinterpretSliceOperands
Sourcefn from_args(args: &[Value]) -> Option<Self>
fn from_args(args: &[Value]) -> Option<Self>
Construct this type from a list of arguments. If not all arguments are
Value, returns
NoneSourcefn as_args(&self) -> Option<Vec<Value>>
fn as_args(&self) -> Option<Vec<Value>>
Turns this type into a flat list of arguments. If not all arguments are
Value,
returns NoneSourcefn as_args_mut(&mut self) -> Option<Vec<&mut Value>>
fn as_args_mut(&mut self) -> Option<Vec<&mut Value>>
Turns this type into a flat list of arguments. If not all arguments are
Value,
returns NoneSourcefn sanitize_args_ptr(&mut self, scope: &Scope)
fn sanitize_args_ptr(&mut self, scope: &Scope)
Sanitize args for the
ptr constraint, loading inputs from pointers for ops that take values.
This is needed because Rust “helpfully” auto-derefs references, skipping the explicit deref
code that inserts a Memory::Load.fn read_pointers(&self) -> Vec<Value>
fn write_pointers(&self) -> Vec<Value>
Sourceimpl PartialEq for ReinterpretSliceOperands
impl PartialEq for ReinterpretSliceOperands
Sourceimpl Serialize for ReinterpretSliceOperands
impl Serialize for ReinterpretSliceOperands
impl StructuralPartialEq for ReinterpretSliceOperands