pub struct SelectOperands {
pub cond: Value,
pub then: Value,
pub or_else: Value,
}Fields
cond: Valuethen: Valueor_else: ValueTrait Implementations
Sourceimpl Clone for SelectOperands
impl Clone for SelectOperands
Sourcefn clone(&self) -> SelectOperands
fn clone(&self) -> SelectOperands
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SelectOperands
impl Debug for SelectOperands
Sourceimpl<'de> Deserialize<'de> for SelectOperands
impl<'de> Deserialize<'de> for SelectOperands
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SelectOperands
Sourceimpl Hash for SelectOperands
impl Hash for SelectOperands
Sourceimpl OperationArgs for SelectOperands
impl OperationArgs for SelectOperands
Sourcefn from_args(args: &[Value]) -> Option<Self>
fn from_args(args: &[Value]) -> Option<Self>
Construct this type from a list of arguments. If not all arguments are
Value, returns
NoneSourcefn as_args(&self) -> Option<Vec<Value>>
fn as_args(&self) -> Option<Vec<Value>>
Turns this type into a flat list of arguments. If not all arguments are
Value,
returns NoneSourcefn as_args_mut(&mut self) -> Option<Vec<&mut Value>>
fn as_args_mut(&mut self) -> Option<Vec<&mut Value>>
Turns this type into a flat list of arguments. If not all arguments are
Value,
returns NoneSourcefn sanitize_args_ptr(&mut self, scope: &Scope)
fn sanitize_args_ptr(&mut self, scope: &Scope)
Sanitize args for the
ptr constraint, loading inputs from pointers for ops that take values.
This is needed because Rust “helpfully” auto-derefs references, skipping the explicit deref
code that inserts a Memory::Load.fn read_pointers(&self) -> Vec<Value>
fn write_pointers(&self) -> Vec<Value>
Sourceimpl PartialEq for SelectOperands
impl PartialEq for SelectOperands
Sourceimpl Serialize for SelectOperands
impl Serialize for SelectOperands
impl StructuralPartialEq for SelectOperands