pub struct StoreOperands {
pub ptr: Value,
pub value: Value,
}Fields
ptr: Valuevalue: ValueTrait Implementations
Sourceimpl Clone for StoreOperands
impl Clone for StoreOperands
Sourcefn clone(&self) -> StoreOperands
fn clone(&self) -> StoreOperands
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoreOperands
impl Debug for StoreOperands
Sourceimpl<'de> Deserialize<'de> for StoreOperands
impl<'de> Deserialize<'de> for StoreOperands
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for StoreOperands
Sourceimpl Hash for StoreOperands
impl Hash for StoreOperands
Sourceimpl OperationArgs for StoreOperands
impl OperationArgs for StoreOperands
Sourcefn from_args(args: &[Value]) -> Option<Self>
fn from_args(args: &[Value]) -> Option<Self>
Construct this type from a list of arguments. If not all arguments are
Value, returns
NoneSourcefn as_args(&self) -> Option<Vec<Value>>
fn as_args(&self) -> Option<Vec<Value>>
Turns this type into a flat list of arguments. If not all arguments are
Value,
returns NoneSourcefn as_args_mut(&mut self) -> Option<Vec<&mut Value>>
fn as_args_mut(&mut self) -> Option<Vec<&mut Value>>
Turns this type into a flat list of arguments. If not all arguments are
Value,
returns NoneSourcefn sanitize_args_ptr(&mut self, scope: &Scope)
fn sanitize_args_ptr(&mut self, scope: &Scope)
Sanitize args for the
ptr constraint, loading inputs from pointers for ops that take values.
This is needed because Rust “helpfully” auto-derefs references, skipping the explicit deref
code that inserts a Memory::Load.fn read_pointers(&self) -> Vec<Value>
fn write_pointers(&self) -> Vec<Value>
Sourceimpl PartialEq for StoreOperands
impl PartialEq for StoreOperands
Sourceimpl Serialize for StoreOperands
impl Serialize for StoreOperands
impl StructuralPartialEq for StoreOperands