Value

Struct Value 

pub struct Value {
    pub kind: ValueKind,
    pub ty: Type,
}

Fields

kind: ValueKindty: Type

Implementations

Source

impl Value

pub fn new(id: Id, ty: Type) -> Self

pub fn constant(value: ConstantValue, ty: impl Into<Type>) -> Self

pub fn elem_type(&self) -> ElemType

pub fn storage_type(&self) -> StorageType

pub fn can_mutate(&self) -> bool

pub fn address_space(&self) -> AddressSpace

pub fn value_type(&self) -> Type

Source

impl Value

pub fn is_immutable(&self) -> bool

Whether a value is always immutable. Used for optimizations to determine whether it’s safe to inline/merge

pub fn is_array_like(&self) -> bool

Is this an array type that yields items when indexed, or a scalar/vector that yields elems/slices when indexed?

pub fn is_value(&self) -> bool

pub fn is_memory(&self) -> bool

Is this an value type that is contained in concrete memory, or a local array/scalar/vector?

pub fn has_buffer_length(&self) -> bool

pub fn is_constant(&self, value: i64) -> bool

Determines if the value is a constant with the specified value (converted if necessary)

pub fn is_true(&self) -> bool

Determines if the value is a boolean constant with the true value

pub fn is_false(&self) -> bool

Determines if the value is a boolean constant with the false value

Source

impl Value

pub fn vector_size(&self) -> usize

pub fn id(&self) -> Id

pub fn as_const(&self) -> Option<ConstantValue>