pub struct IndexOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
memory_index_checked | ATTR_KEY_MEMORY_INDEX_CHECKED | UnitAttr |
Implementations
Sourceimpl IndexOp
impl IndexOp
Sourcepub fn get_attr_memory_index_checked<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, UnitAttr>>
pub fn get_attr_memory_index_checked<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, UnitAttr>>
Get a Ref to the value of the attribute named memory_index_checked.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_memory_index_checked(&self, ctx: &Context, value: UnitAttr)
pub fn set_attr_memory_index_checked(&self, ctx: &Context, value: UnitAttr)
Set the value of the attribute named memory_index_checked.
Sourceimpl IndexOp
impl IndexOp
pub fn new( ctx: &mut Context, base: Value, index: Value, checked: Option<UnitAttr>, ) -> Self
pub fn base(&self, ctx: &Context) -> Value
pub fn base_as_use(&self, ctx: &Context) -> Use<Value>
pub fn index(&self, ctx: &Context) -> Value
pub fn index_as_use(&self, ctx: &Context) -> Use<Value>
pub fn checked<'a>(&self, ctx: &'a Context) -> bool
pub fn set_checked(&self, ctx: &Context)
pub fn remove_checked(&self, ctx: &Context)