pub struct CompositeInsertOp { /* private fields */ }Expand description
Attribute(s):
Note: Only attributes defined directly as part of this operation are listed here. There may be others, not listed here, defined by interface implementations.
| Name | Static Name Identifier | Type |
|---|---|---|
composite_insert_index | ATTR_KEY_COMPOSITE_INSERT_INDEX | IndexAttr |
Implementations
Sourceimpl CompositeInsertOp
impl CompositeInsertOp
Sourcepub fn get_attr_composite_insert_index<'a>(
&self,
ctx: &'a Context,
) -> Option<Ref<'a, IndexAttr>>
pub fn get_attr_composite_insert_index<'a>( &self, ctx: &'a Context, ) -> Option<Ref<'a, IndexAttr>>
Get a Ref to the value of the attribute named composite_insert_index.
The Ref is a borrow of the containing Operation object.
Sourcepub fn set_attr_composite_insert_index(&self, ctx: &Context, value: IndexAttr)
pub fn set_attr_composite_insert_index(&self, ctx: &Context, value: IndexAttr)
Set the value of the attribute named composite_insert_index.
Sourceimpl CompositeInsertOp
impl CompositeInsertOp
pub fn new( ctx: &mut Context, composite: Value, value: Value, index: impl Into<IndexAttr>, ) -> Self
pub fn composite(&self, ctx: &Context) -> Value
pub fn composite_as_use(&self, ctx: &Context) -> Use<Value>
pub fn value(&self, ctx: &Context) -> Value
pub fn value_as_use(&self, ctx: &Context) -> Use<Value>
pub fn index<'a>(&self, ctx: &'a Context) -> Ref<'a, IndexAttr>
pub fn set_index(&self, ctx: &Context, value: impl Into<IndexAttr>)