pub enum BarrierOps {
Show 15 variants
Init {
barrier: Value,
is_elected: Value,
arrival_count: Value,
},
InitManual {
barrier: Value,
arrival_count: Value,
},
MemCopyAsync {
barrier: Value,
source: Value,
destination: Value,
source_length: Value,
},
MemCopyAsyncCooperative {
barrier: Value,
source: Value,
destination: Value,
source_length: Value,
},
MemCopyAsyncTx {
barrier: Value,
source: Value,
destination: Value,
source_length: Value,
},
CopyAsync {
source: Value,
destination: Value,
source_length: Value,
copy_length: u32,
checked: bool,
},
TmaLoad {
barrier: Value,
tensor_map: Value,
destination: Value,
indices: Vec<Value>,
},
TmaLoadIm2col {
barrier: Value,
tensor_map: Value,
destination: Value,
indices: Vec<Value>,
offsets: Vec<Value>,
},
Arrive {
barrier: Value,
},
ArriveTx {
barrier: Value,
arrive_count_update: Value,
transaction_count_update: Value,
},
CommitCopyAsync {
barrier: Value,
},
ExpectTx {
barrier: Value,
transaction_count_update: Value,
},
Wait {
barrier: Value,
token: Value,
},
WaitParity {
barrier: Value,
phase: Value,
},
ArriveAndWait {
barrier: Value,
},
}Expand description
Operations available on a barrier
Variants
Init
Initialize the barrier, optionally with a cta proxy fence
InitManual
Manually initialize the barrier with an arrival count, without any sync or election handling
MemCopyAsync
Copy source to destination
MemCopyAsyncCooperative
Copy source to destination, with cooperative behaviour
MemCopyAsyncTx
Copy source to destination, with transaction count
CopyAsync
Copy source to destination
TmaLoad
TmaLoadIm2col
Arrive
Arrives at the barrier (decrements barrier count)
ArriveTx
CommitCopyAsync
ExpectTx
Wait
WaitParity
ArriveAndWait
Waits until data is loaded