pub struct CubeMmaConfig {
pub a_type: StorageType,
pub b_type: StorageType,
pub cd_type: StorageType,
pub m_granularity: u32,
pub m_max: u32,
pub n_granularity: u32,
pub n_max: u32,
pub k_granularity: u32,
pub k_max: u32,
pub units_per_block: Option<u32>,
}Expand description
Shape and element types of a valid flexible MMA configuration
Only Vulkan for now, but this should also be usable for wgmma/xmma on datacenter CUDA.
Actual matrix size must be multiple of granularity and <= max.
Fields
a_type: StorageTypeElement of the A matrix
b_type: StorageTypeElement of the B matrix
cd_type: StorageTypeElement of the C/D matrices
m_granularity: u32The granularity of the matrix on the m dimension
m_max: u32The maximum value for m
n_granularity: u32The size of the matrix on the n dimension
n_max: u32The maximum value for n
k_granularity: u32The size of the matrix on the k dimension
k_max: u32The maximum value for k
units_per_block: Option<u32>The number of units that must be in the cube for this configuration to be valid.
None means it’s always valid (but might still have an optimal value).