Features

Struct Features 

pub struct Features {
    pub plane: EnumSet<Plane>,
    pub cube_cluster: bool,
    pub memory_reinterpret: bool,
    pub alignment: bool,
    pub types: Types,
    pub matmul: MatmulFeatures,
    pub copy_async: bool,
    pub tma: EnumSet<Tma>,
    pub unaligned_io: bool,
}
Features supported by a runtime

Fields

plane: EnumSet<Plane>

Plane features supported by this runtime.

cube_cluster: bool

Clustered launches and intra-cluster operations like cluster shared memory

memory_reinterpret: bool

Enables changing the type of containers during kernel execution.

alignment: bool

Enables explicit alignment. If false, alignment still compiles, but isn’t actually applied.

types: Types

Type support

matmul: MatmulFeatures

Matrix multiplication features

copy_async: bool

Whether copy_async is supported

tma: EnumSet<Tma>

Tensor Memory Accelerator supported features

unaligned_io: bool

Whether vectors can be read from / stored to addresses not aligned with the vector_size

Implementations

Source

impl Features

pub fn type_usage(&self, ty: StorageType) -> EnumSet<TypeUsage>

Get the usages for a type

pub fn complex_usage(&self, ty: StorageType) -> EnumSet<ComplexUsage>

Get the complex capability families for a type.

pub fn atomic_type_usage(&self, ty: Type) -> EnumSet<AtomicUsage>

Get the usages for an atomic type

pub fn supports_type(&self, ty: impl Into<Type>) -> bool

Whether the type is supported in any way

pub fn supports_address(&self, ty: impl Into<AddressType>) -> bool

Whether the address type is supported in any way

pub fn supports_complex_usage( &self, ty: impl Into<StorageType>, usage: ComplexUsage, ) -> bool

Whether a complex storage type supports the requested capability family.