pub struct MatmulFeatures {
pub cmma: BTreeSet<MmaConfig>,
pub mma: BTreeSet<MmaConfig>,
pub scaled_mma: BTreeSet<ScaledMmaConfig>,
pub ldmatrix: BTreeSet<StorageType>,
pub stmatrix: BTreeSet<StorageType>,
}Expand description
Matrix multiplication-related features
Fields
cmma: BTreeSet<MmaConfig>The cmma feature enables cooperative matrix-multiply and accumulate operations.
mma: BTreeSet<MmaConfig>The manual MMA feature enables cooperative matrix-multiply with manually managed data movement
scaled_mma: BTreeSet<ScaledMmaConfig>Scaled MMA allows combining matrix multiplication with unscaling quantized values into a single instruction. Scales must fit a specific layout and block size.
ldmatrix: BTreeSet<StorageType>Types supported for ldmatrix, if any
stmatrix: BTreeSet<StorageType>Types supported by stmatrix, if any