pub struct SmallMap<K, V, const N: usize>(/* private fields */);Expand description
A hash map, with a fast non-cryptographic hasher and deterministic iteration order, optimized for the common case of very few entries.
Up to N entries are stored inline, in a flat, linearly-scanned
array, with no heap allocation and no hashing. Once an insert
grows the map past N entries, it transparently and permanently
promotes itself to an IMap
Implementations
Sourceimpl<K, V, const N: usize> SmallMap<K, V, N>
impl<K, V, const N: usize> SmallMap<K, V, N>
Sourcepub fn new() -> SmallMap<K, V, N>
pub fn new() -> SmallMap<K, V, N>
Creates an empty SmallMap. Does not allocate until it grows
past N entries.
Sourcepub fn is_inline(&self) -> bool
pub fn is_inline(&self) -> bool
Returns true if this map has not (yet) grown past N
entries, i.e., is still using inline, non-heap-allocated
storage.
Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Clears the map, removing all key-value pairs. A previously promoted map stays promoted; see the SmallMap documentation.
Sourcepub fn retain<F>(&mut self, f: F)
pub fn retain<F>(&mut self, f: F)
Retains only the elements specified by the predicate.
In other words, remove all pairs (k, v) such that f(&k, &mut v) returns false.
Sourcepub fn iter_mut(&mut self) -> MapIterMut<'_, K, V> ⓘ
pub fn iter_mut(&mut self) -> MapIterMut<'_, K, V> ⓘ
Returns a mutable iterator over the map’s key-value pairs.
Sourcepub fn values_mut(&mut self) -> impl Iterator<Item = &mut V>
pub fn values_mut(&mut self) -> impl Iterator<Item = &mut V>
Returns a mutable iterator over the map’s values.
Sourceimpl<K, V, const N: usize> SmallMap<K, V, N>
impl<K, V, const N: usize> SmallMap<K, V, N>
Sourcepub fn insert(&mut self, key: K, value: V) -> Option<V>
pub fn insert(&mut self, key: K, value: V) -> Option<V>
Inserts a key-value pair into the map.
If the map did not have this key present, None is returned.
If the map did have this key present, the value is updated,
and the old value is returned. The key is not updated, though;
this matters for types that can be == without being
identical.
Sourcepub fn get<Q>(&self, key: &Q) -> Option<&V>
pub fn get<Q>(&self, key: &Q) -> Option<&V>
Returns a reference to the value corresponding to the key.
Sourcepub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
pub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
Returns a mutable reference to the value corresponding to the key.
Sourcepub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
pub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
Returns the key-value pair corresponding to the supplied key.
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Returns true if the map contains a value for the specified
key.