pub struct Dim3 {
pub x: u32,
pub y: u32,
pub z: u32,
}Expand description
The number of units across all 3 axis totalling to the number of working units in a cube.
Fields
x: u32The number of units in the x axis.
y: u32The number of units in the y axis.
z: u32The number of units in the z axis.
Implementations
Sourceimpl Dim3
impl Dim3
Sourcepub const fn new_single() -> Self
pub const fn new_single() -> Self
Create a new Dim3 with x = y = z = 1.
Sourcepub const fn new_2d(x: u32, y: u32) -> Self
pub const fn new_2d(x: u32, y: u32) -> Self
Create a new dim3 with the given x and y, and z = 1.
Sourcepub const fn new_3d(x: u32, y: u32, z: u32) -> Self
pub const fn new_3d(x: u32, y: u32, z: u32) -> Self
Create a new Dim3 with the given x, y and z.
This is equivalent to the new function.
Sourcepub const fn can_contain(&self, other: Dim3) -> bool
pub const fn can_contain(&self, other: Dim3) -> bool
Whether this Dim3 can fully contain other