pub struct Value {
pub kind: ValueKind,
pub ty: Type,
}Fields
kind: ValueKindty: TypeImplementations
Sourceimpl Value
impl Value
pub fn new(id: Id, ty: Type) -> Self
pub fn constant(value: ConstantValue, ty: impl Into<Type>) -> Self
pub fn elem_type(&self) -> ElemType
pub fn storage_type(&self) -> StorageType
pub fn can_mutate(&self) -> bool
pub fn address_space(&self) -> AddressSpace
pub fn value_type(&self) -> Type
Sourceimpl Value
impl Value
Sourcepub fn is_immutable(&self) -> bool
pub fn is_immutable(&self) -> bool
Whether a value is always immutable. Used for optimizations to determine whether it’s safe to inline/merge
Sourcepub fn is_array_like(&self) -> bool
pub fn is_array_like(&self) -> bool
Is this an array type that yields items when indexed, or a scalar/vector that yields elems/slices when indexed?
pub fn is_value(&self) -> bool
Sourcepub fn is_memory(&self) -> bool
pub fn is_memory(&self) -> bool
Is this an value type that is contained in concrete memory, or a local array/scalar/vector?
pub fn has_buffer_length(&self) -> bool
Sourcepub fn is_constant(&self, value: i64) -> bool
pub fn is_constant(&self, value: i64) -> bool
Determines if the value is a constant with the specified value (converted if necessary)